@@ -551,7 +551,7 @@ wccp2_add_service_list(int service, int service_id, int service_priority,
 }
 
 static struct wccp2_service_list_t *
-            wccp2_get_service_by_id(int service, int service_id) {
+wccp2_get_service_by_id(int service, int service_id) {
 
     struct wccp2_service_list_t *p;
 
@@ -1271,6 +1271,7 @@ wccp2HandleUdp(int sock, void *not_used)
             /* Nothing to do for the types below */
 
         case WCCP2_ASSIGN_MAP:
+        case WCCP2_REDIRECT_ASSIGNMENT:
             break;
 
         default:
@@ -2278,7 +2279,7 @@ parse_wccp2_service_ports(char *options, int portlist[])
         port = strsep(&tmp2, ",");
     }
 
-    if (i == 8) {
+    if (i == WCCP2_NUMPORTS && port) {
         fatalf("parse_wccp2_service_ports: too many ports (maximum: 8) in list '%s'\n", options);
     }
 
